@@ -20,10 +20,13 @@
 # Authors:
 #      Mathias Hasselmann
 #
+
 test -n "$EPC_DEBUG" && echo "$0: running $1..."
 
-EPC_DEBUG="${EPC_DEBUG:-1}" \
-G_DEBUG="${G_DEBUG:-fatal-warnings}" \
+default_system_bus_address=$(pkg-config dbus-1 --variable=system_bus_default_address)
+
+EPC_DEBUG="${EPC_DEBUG:-1}" G_DEBUG="${G_DEBUG:-fatal-warnings}" \
+DBUS_SYSTEM_BUS_ADDRESS="${DBUS_SYSTEM_BUS_ADDRESS:-${default_system_bus_address}}" \
 "$@" 2> "$1.err" > "$1.out"
 
 result=$?
